@@ -12,9 +12,18 @@ import click
 # Local imports
 from ugc import __version__, commands
 from ugc.grades import Grades
+from ugc.config import ConfigValidationError
 
 pass_grades = click.make_pass_decorator(Grades, ensure=True)
 
+
+def print_error(context):
+    click.secho(
+        f"The configuration file contains errors. Got:\n{context.error}",
+        fg="bright_red",
+    )
+
+
 # From https://click.palletsprojects.com/en/8.0.x/commands/#decorating-commands
 # There might be a more elegant way to do this, but it works well...
 # No function with the `run_if_config_exists` decorator will execute if the
@@ -25,6 +34,8 @@ def run_if_config_exists(f):
         # invoke command only when attribute `config_exists` is set to True
         if ctx.obj.config_exists:
             return ctx.invoke(f, ctx.obj, *args, **kwargs)
+        else:
+            print_error(ctx.obj)
         return None
 
     return update_wrapper(new_func, f)
@@ -40,6 +51,7 @@ def print_version(context, param, value):
 
 @click.group()
 @click.option(
+    "-v",
     "--version",
     is_flag=True,
     callback=print_version,
@@ -50,12 +62,23 @@ def print_version(context, param, value):
 @click.option(
     "--config",
     default=f"{str(Path.home())}/.ugc-grades.json",
+    type=str,
     show_default=True,
     help="Custom path to config file.",
 )
+@click.option(
+    "--json",
+    "json_str",
+    type=str,
+    default=None,
+    help="Load grades data from a JSON string.",
+)
 @click.pass_context
-def cli(ctx, config):
-    ctx.obj = Grades(config_path=config)
+def cli(ctx, config, json_str):
+    try:
+        ctx.obj = Grades(json_str=json_str, config_path=config)
+    except ConfigValidationError as error:
+        ctx.obj = Grades(verified=False, error=error)
 
 
 @cli.group()
@@ -108,6 +131,8 @@ def progress(ctx, grades, avg_progress_only):
 @pass_grades
 def generate_sample(grades, force_overwrite):
     """Generate a sample grades JSON config file."""
+    if grades.error:
+        print_error(grades)
     if force_overwrite:
         return commands.generate_sample_overwrite(grades.config)
     return commands.generate_sample(grades.config)
